#!/usr/bin/env bash
#
# build_p4ruby.sh
#
# This provides our "build step" for the CD chain. We perform tests using the
# latest build of p4d and the p4api. If it's all ok, then the prelease gem
# is uploaded to our internal Gem server for further validation.
#
# Installation Dependencies
# -------------------------
#
# - RVM to manage the Ruby installation
# - The RVM version under test should have the 'inabox' gem installed and
#   configured to post to http://geminabox.das.perforce.com
# - Ant to execute our DocBook installation
#
# Usage
# -----
#

set -e
export PATH="$PATH:$HOME/.rvm/bin"

# Note that rvm seems to select 2.1.3 if you just specify 2.1
echo "RUBY_USE_VERSION=${RUBY_USE_VERSION}"

rvm use ${RUBY_USE_VERSION}

set -v

bundle install

if [ ! -f work/p4d ]; then
    gem install p4util --version 0.0.3
    p4util download p4d
    gem uninstall p4util p4ruby
fi

bundle exec rake compile test package build.properties

# Note that this requires RUBY_CC_VERSION set to the available Ruby versions
# and P4RUBY_CROSS_PLATFORM set to the right platform
if [ -n "${P4RUBY_CROSS_PLATFORM}" ]; then
    bundle exec rake cross native gem
fi

gem inabox pkg/p4ruby*.gem -g http://geminabox.das.perforce.com

